[ ![Documentation](https://img.shields.io/badge/sphinx-documentation-informational.svg)](https://opentisim.readthedocs.org)
[ ![License: MIT](https://img.shields.io/badge/License-MIT-informational.svg)](https://github.com/TUDelft-CITG/Terminal-Optimization/blob/master/LICENSE.txt)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3341606.svg)](https://doi.org/10.5281/zenodo.3341606)

[![CircleCI](https://circleci.com/gh/TUDelft-CITG/OpenTISim.svg?style=svg&circle-token=e80be990a1415185a3aee7c7304e86bbef094eb5)](https://circleci.com/gh/TUDelft-CITG/OpenTISim)

# OpenTISim

**Open** source **T**erminal **I**nvestment **Sim**ulation - Terminal investment strategy analysis, parametrically driven by changing demand scenarios.

Documentation can be found: [here](https://opentisim.readthedocs.org)

## Installation

To install OpenTISim, run this command in your terminal:

``` bash
pip install opentisim
```

This is the preferred method to install OpenTISim, as it will always install the most recent stable release.

If you don not have [pip](https://pip.pypa.io) installed, this [Python installation guide](http://docs.python-guide.org/en/latest/starting/installation/) can guide you through the process.

You can read the [documentation](https://opentisim.readthedocs.io/en/latest/installation.html) for other installation methods.
